@@ -68,4 +68,4 @@ class DBWrapperPgSQL(DBWrapperPgSQLMixin, DBWrapper):
             params (tuple[Any, ...]): The parameters to log.
         """
         queryString = query.as_string(self.dbCursor)
-        logging.getLogger().debug(f"Query: {queryString}")
+        logging.getLogger().debug(f"Query: {queryString} with params: {params}")
